@@ -135,6 +135,11 @@ KISAO_SIMULATION_METHOD_ARGUMENTS_MAP = OrderedDict([
                 'name': 'relative tolerance',
                 'type': ValueType.float,
             },
+            'KISAO_0000415': {
+                'id': 'max_sim_steps',
+                'name': 'Maximum simulation steps',
+                'type': ValueType.integer,
+            },
             'KISAO_0000525': {
                 'id': 'stop_if',
                 'name': 'stop condition',
@@ -152,6 +157,11 @@ KISAO_SIMULATION_METHOD_ARGUMENTS_MAP = OrderedDict([
                 'name': 'random number generator seed',
                 'type': ValueType.integer,
             },
+            'KISAO_0000415': {
+                'id': 'max_sim_steps',
+                'name': 'Maximum simulation steps',
+                'type': ValueType.integer,
+            },
             'KISAO_0000525': {
                 'id': 'stop_if',
                 'name': 'stop condition',
@@ -169,6 +179,11 @@ KISAO_SIMULATION_METHOD_ARGUMENTS_MAP = OrderedDict([
                 'name': 'random number generator seed',
                 'type': ValueType.integer,
             },
+            'KISAO_0000415': {
+                'id': 'max_sim_steps',
+                'name': 'Maximum simulation steps',
+                'type': ValueType.integer,
+            },
             'KISAO_0000525': {
                 'id': 'stop_if',
                 'name': 'stop condition',
@@ -186,6 +201,11 @@ KISAO_SIMULATION_METHOD_ARGUMENTS_MAP = OrderedDict([
                 'name': 'random number generator seed',
                 'type': ValueType.integer,
             },
+            'KISAO_0000415': {
+                'id': 'max_sim_steps',
+                'name': 'Maximum simulation steps',
+                'type': ValueType.integer,
+            },
             'KISAO_0000525': {
                 'id': 'stop_if',
                 'name': 'stop condition',
